@@ -5,7 +5,7 @@
 # use lib '......';
 use TripleDES;
 
- $crpt = CriptData("sicret_credit_card=4557024001932895","Unhackable_password");
+ $crpt = CriptData("secret_credit_card=4557024001932895","Unhackable_password");
  print "My data now is crypted like: $crpt\n";
 
  $encrpt = EncriptData($crpt,"Unhackable_password");
