@@ -14,7 +14,7 @@
 #################################################
 # send_mail(FROM,TO,SUBJECT,BODY,AS_HTML);
 #################################################
-require './conf/config.pl';
+if(!$sys_config_pl_loaded) {require './conf/config.pl';}
 
 %mole_attached_files = ();  # Please use "set_mail_attachment" and "remove_mail_attachment"
                             # instead of direct manipulating of hash.
